import 'package:flutter/material.dart';
import 'types.dart';

class StyleSheet {
  final Map<String, Style> styles;

  const StyleSheet.create(this.styles);

  Style operator [](String key) {
    if (styles.containsKey(key)) {
      return styles[key];
    }

    return Style();
  }
}

class Style {
  /// Alignment
  // final AlignContent alignContent;
  final AlignItems alignItems;
  // final AlignSelf alignSelf;
  final double aspectRatio;
  final BorderSide border;
  final BorderSide borderTop;
  final BorderSide borderBottom;
  final BorderSide borderLeft;
  final BorderSide borderRight;
  // final Position position;
  final Direction direction;
  final int flex;
  // final FlexBasis flexBasis;
  final FlexDirection flexDirection;
  // final double flexGrow;
  // final double flexShrink;
  // final FlexWrap flexWrap;
  final double width;
  final double height;
  final JustifyContent justifyContent;
  final EdgeInsets margin;
  // final double maxHeight;
  // final double maxWidth;
  // final double minHeight;
  // final double minWidth;
  // final overflow
  final EdgeInsets padding;
  // final zIndex
  // final double backfaceVisibility;
  final Color backgroundColor;
  final double opacity;
  final int elevation;
  final List<BoxShadow> shadow;
  final BorderRadiusGeometry borderRadius;

  const Style({
    // this.alignContent = AlignContent.flexStart,
    this.alignItems = AlignItems.flexStart,
    // this.alignSelf = AlignSelf.flexStart,
    this.aspectRatio,
    this.border,
    this.borderTop = BorderSide.none,
    this.borderBottom = BorderSide.none,
    this.borderLeft = BorderSide.none,
    this.borderRight = BorderSide.none,
    this.direction = Direction.inherit,
    this.flex,
    // this.flexBasis,
    this.flexDirection,
    // this.flexGrow,
    // this.flexShrink,
    // this.flexWrap,
    this.width,
    this.height,
    this.justifyContent = JustifyContent.flexStart,
    this.margin,
    // this.maxHeight,
    // this.maxWidth,
    // this.minHeight,
    // this.minWidth,
    this.padding = const EdgeInsets.all(0),
    this.backgroundColor,
    this.elevation,
    this.opacity,
    this.shadow,
    this.borderRadius,
  });
}

const kJustifyContentToMainAxisAlignment = <JustifyContent, MainAxisAlignment>{
  JustifyContent.flexStart: MainAxisAlignment.start,
  JustifyContent.flexEnd: MainAxisAlignment.end,
  JustifyContent.center: MainAxisAlignment.center,
  JustifyContent.spaceBetween: MainAxisAlignment.spaceBetween,
  JustifyContent.spaceAround: MainAxisAlignment.spaceAround,
  JustifyContent.spaceEvenly: MainAxisAlignment.spaceEvenly,
};

const kAlignItemsToCrossAxisAlignment = <AlignItems, CrossAxisAlignment>{
  AlignItems.flexStart: CrossAxisAlignment.start,
  AlignItems.flexEnd: CrossAxisAlignment.end,
  AlignItems.center: CrossAxisAlignment.center,
  AlignItems.stretch: CrossAxisAlignment.stretch,
  AlignItems.baseline: CrossAxisAlignment.baseline,
};
