import 'package:flutter/material.dart';
import '../types.dart';
import '../style.dart';

class View extends StatelessWidget {
  final Style style;
  final Widget child;
  final Iterable<Widget> children;

  const View._(this.style, this.child, this.children);

  factory View({Style style, Widget child, Iterable<Widget> children}) {
    if (style == null) {
      style = Style();
    }

    if (children == null && child != null) {
      children = <Widget>[child];
    }

    return View._(style, child, children);
  }

  BoxBorder _buildBorder() {
    if (style.border != null) {
      return Border.all(
        style: style.border.style,
        color: style.border.color,
        width: style.border.width,
      );
    }

    return Border(
      top: style.borderTop,
      right: style.borderRight,
      bottom: style.borderBottom,
      left: style.borderLeft,
    );
  }

  @override
  Widget build(BuildContext context) {
    Widget layout = Container(
      padding: style.padding,
      margin: style.margin,
      decoration: BoxDecoration(
        color: style.backgroundColor,
        border: _buildBorder(),
        boxShadow: style.elevation != null
            ? kElevationToShadow[style.elevation]
            : style.shadow,
        borderRadius: style.borderRadius,
      ),
      child: Flex(
        children: children ?? <Widget>[],
        direction: style.flexDirection == FlexDirection.row
            ? Axis.horizontal
            : Axis.vertical,
        mainAxisAlignment:
            kJustifyContentToMainAxisAlignment[style.justifyContent],
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: kAlignItemsToCrossAxisAlignment[style.alignItems],
        verticalDirection: VerticalDirection.down,
      ),
    );

    if (style.aspectRatio != null) {
      layout = AspectRatio(
        aspectRatio: style.aspectRatio,
        child: layout,
      );
    }

    if (style.width != null || style.height != null) {
      layout = SizedBox(
        width: style.width,
        height: style.height,
        child: layout,
      );
    }

    if (style.direction != Direction.inherit) {
      layout = Directionality(
        textDirection: style.direction == Direction.ltr
            ? TextDirection.ltr
            : TextDirection.rtl,
        child: layout,
      );
    }

    if (style.flex != null) {
      layout = Expanded(
        flex: style.flex,
        child: layout,
      );
    }

    if (style.opacity != null) {
      layout = Opacity(
        opacity: style.opacity,
        child: layout,
      );
    }

    return layout;
  }
}
